@@ -76,3 +76,25 @@ IfInteger <- function(x)
   else { return(FALSE) }
 }
 
+
+
+# A vector containing names of the calculated distance measures between fuzzy numbers.
+
+distanceNames <- c("Euclidean", "AHD", "HSD")
+
+# A vector containing names of the types of the calculated errors.
+
+errorTypes <- c("MAE","WMAE","MSE","WMSE","NRMSE")
+
+# A vector containing names of the types of the calculated statistical measures.
+
+measuresTypes <- c("TrueMean","ImpMean", "AbsDiffTrueImpMean", "GenMean","GenImpMean", "AbsDiffGenImpMean","TrueSD","ImpSD",
+                   "AbsDiffTrueImpSD","GenSD","GenImpSD","AbsDiffGenImpSD")
+
+# A vector containing names of the subsets used in the epistemic tests.
+
+setsNames <- c("true","imputed", "parts")
+
+# A vector containing names of the types of the applied epistemic tests.
+
+testsNames <- c("avs-anti","ms-anti","res-anti")
